from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean

Showpep_V0_1_0 = CommandToolBuilder(tool="showpep", base_command=["showpep"], inputs=[ToolInput(tag="in_format", input_type=Boolean(optional=True), prefix="-format", doc=InputDocumentation(doc="menu       [2] Display format (Values: 0 (Enter your\nown list of things to display); 1 (Sequence\nonly); 2 (Default sequence with features); 3\n(Pretty sequence 4:Baroque))")), ToolInput(tag="in_uppercase", input_type=Boolean(optional=True), prefix="-uppercase", doc=InputDocumentation(doc="range      [If this is left blank, then the sequence\ncase is left alone.] Regions to put in\nuppercase.\nIf this is left blank, then the sequence\ncase is left alone.\nA set of regions is specified by a set of\npairs of positions.\nThe positions are integers.\nThey are separated by any non-digit,\nnon-alpha character.\nExamples of region specifications are:\n24-45, 56-78\n1:45, 67=99;765..888\n1,5,8,10,23,45,57,99")), ToolInput(tag="in_highlight", input_type=Boolean(optional=True), prefix="-highlight", doc=InputDocumentation(doc="range      [(full sequence)] Regions to colour if\nformatting for HTML.\nIf this is left blank, then the sequence is\nleft alone.\nA set of regions is specified by a set of\npairs of positions.\nThe positions are integers.\nThey are followed by any valid HTML font\ncolour.\nExamples of region specifications are:\n24-45 blue 56-78 orange\n1-100 green 120-156 red\nA file of ranges to colour (one range per\nline) can be specified as '@filename'.")), ToolInput(tag="in_annotation", input_type=Boolean(optional=True), prefix="-annotation", doc=InputDocumentation(doc="range      [If this is left blank, then no annotation\nis added.] Regions to annotate by marking.\nIf this is left blank, then no annotation is\nadded.\nA set of regions is specified by a set of\npairs of positions followed by optional\ntext.\nThe positions are integers.\nThey are followed by any text (but not\ndigits when on the command-line).\nExamples of region specifications are:\n24-45 new domain 56-78 match to Mouse\n1-100 First part 120-156 oligo\nA file of ranges to annotate (one range per\nline) can be specified as '@filename'.")), ToolInput(tag="in_source_match", input_type=Boolean(optional=True), prefix="-sourcematch", doc=InputDocumentation(doc="string     [*] By default any feature source in the\nfeature table is shown. You can set this to\nmatch any feature source you wish to show.\nThe source name is usually either the name\nof the program that detected the feature or\nit is the feature table (eg: EMBL) that the\nfeature came from.\nThe source may be wildcarded by using '*'.\nIf you wish to show more than one source,\nseparate their names with the character '|',\neg:\ngene* | embl (Any string)")), ToolInput(tag="in_type_match", input_type=Boolean(optional=True), prefix="-typematch", doc=InputDocumentation(doc="string     [*] By default any feature type in the\nfeature table is shown. You can set this to\nmatch any feature type you wish to show.\nSee http://www.ebi.ac.uk/embl/WebFeat/ for a\nlist of the EMBL feature types and see\nAppendix A of the Swissprot user manual in\nhttp://www.expasy.org/sprot/userman.html for\na list of the Swissprot feature types.\nThe type may be wildcarded by using '*'.\nIf you wish to show more than one type,\nseparate their names with the character '|',\neg:\n*UTR | intron (Any string)")), ToolInput(tag="in_min_score", input_type=Boolean(optional=True), prefix="-minscore", doc=InputDocumentation(doc="float      [0.0] Minimum score of feature to display\n(see also maxscore) (Any numeric value)")), ToolInput(tag="in_max_score", input_type=Boolean(optional=True), prefix="-maxscore", doc=InputDocumentation(doc="float      [0.0] Maximum score of feature to display.\nIf both minscore and maxscore are zero (the\ndefault), then any score is ignored (Any\nnumeric value)")), ToolInput(tag="in_tag_match", input_type=Boolean(optional=True), prefix="-tagmatch", doc=InputDocumentation(doc="string     [*] Tags are the types of extra values that\na feature may have. By default any feature\ntag in the feature table is shown. You can\nset this to match any feature tag you wish\nto show.\nThe tag may be wildcarded by using '*'.\nIf you wish to show more than one tag,\nseparate their names with the character '|',\neg:\ngene | label (Any string)")), ToolInput(tag="in_value_match", input_type=Boolean(optional=True), prefix="-valuematch", doc=InputDocumentation(doc="string     [*] Tag values are the values associated\nwith a feature tag. Tags are the types of\nextra values that a feature may have. By\ndefault any feature tag value in the feature\ntable is shown. You can set this to match\nany feature tag value you wish to show.\nThe tag value may be wildcarded by using\n'*'.\nIf you wish to show more than one tag value,\nseparate their names with the character\n'|', eg:\npax* | 10 (Any string)")), ToolInput(tag="in_strict_tags", input_type=Boolean(optional=True), prefix="-stricttags", doc=InputDocumentation(doc="boolean    [N] By default if any tag/value pair in a\nfeature matches the specified tag and value,\nthen all the tags/value pairs of that\nfeature will be displayed. If this is set to\nbe true, then only those tag/value pairs in\na feature that match the specified tag and\nvalue will be displayed.")), ToolInput(tag="in_three_letter", input_type=Boolean(optional=True), prefix="-threeletter", doc=InputDocumentation(doc="boolean    [N] Display protein sequences in\nthree-letter code")), ToolInput(tag="in_number", input_type=Boolean(optional=True), prefix="-number", doc=InputDocumentation(doc="boolean    [N] Number the sequences")), ToolInput(tag="in_width", input_type=Boolean(optional=True), prefix="-width", doc=InputDocumentation(doc="integer    [60] Width of sequence to display (Integer 1\nor more)")), ToolInput(tag="in_length", input_type=Boolean(optional=True), prefix="-length", doc=InputDocumentation(doc="integer    [0] Line length of page (0 for indefinite)\n(Integer 0 or more)")), ToolInput(tag="in_margin", input_type=Boolean(optional=True), prefix="-margin", doc=InputDocumentation(doc="integer    [10] Margin around sequence for numbering\n(Integer 0 or more)")), ToolInput(tag="in_offset", input_type=Boolean(optional=True), prefix="-offset", doc=InputDocumentation(doc="integer    [1] Offset to start numbering the sequence\nfrom (Any integer value)")), ToolInput(tag="in_html", input_type=Boolean(optional=True), prefix="-html", doc=InputDocumentation(doc="boolean    [N] Use HTML formatting"))], outputs=[], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Showpep_V0_1_0().translate("wdl", allow_empty_container=True)

